@@ -2,7 +2,7 @@
 ORIGINAL FILENAME:
     gtoken.py
 SOURCE PROJECT:
-    ssut/py-googletrans (https://github.com/ssut/py-googletrans)\n
+    ssut/py-googletrans (https://github.com/ssut/py-googletrans)
 AUTHOR:
     SuHun Han (@ssut on GitHub)
 EXPLANATION:
@@ -241,4 +241,4 @@ class TokenAcquirer:
     def do(self, text):
         self._update()
         tk = self.acquire(text)
-        return tk
\ No newline at end of file
+        return tk
